@@ -1,7 +1,6 @@
-import multiprocessing
 import threading
-import time
 from threading import Thread
+from time import sleep
 
 from pyOptional import Optional
 
@@ -18,9 +17,8 @@ thread_list = list()
 
 
 class ScenarioMonitor(object):
-    screen_shot_generator: ScreenShotGenerator
     PERIOD = 1000
-    cpu_stats = list()
+    cpu_monitor = list()
     memory_stats = list()
     activities = list()
     smartBOT = SmartBOT
@@ -28,18 +26,14 @@ class ScenarioMonitor(object):
     timer = threading.Timer
     take_screenshots = True
     threads = []
-    screen_shot_generator: ScreenShotGenerator
+    screenshots = []
 
     def __init__(self, smartBOT):
         self.smartBOT = smartBOT
-        self.screen_shot_generator = ScreenShotGenerator(self.smartBOT)
-        # self.countdown = Thread(target=self.thread_start())
-        # define countdown if required
 
     def thread_start(self):
         try:
-            # while 1:
-            time.sleep(.003 * self.PERIOD)
+            sleep(.003 * self.PERIOD)
 
         except ValueError as error:
             print(error)
@@ -48,34 +42,40 @@ class ScenarioMonitor(object):
         interval = int(self.PERIOD / 1000)
         Commons().create_temp_folder(self.smartBOT)
 
-        cpu_details = CpuMonitor(self.cpu_stats, self.smartBOT, interval)
-        monitor_cpu_thread = multiprocessing.Process(target=cpu_details.monitor_cpu_details)
+        cpu_details = CpuMonitor(self.smartBOT)
 
-        screen_shot_thread = multiprocessing.Process(target=self.screen_shot_generator.generate_screenshot)
+        # monitor_cpu_thread = multiprocessing.Process(target=cpu_details.monitor_cpu_details)
+        # screen_shot_thread = multiprocessing.Process(target=self.method_name().generate_screenshot)
+        self.screenshot_generator(self.smartBOT).generate_screenshot()
+        self.cpu_monitor(self.smartBOT).monitor_cpu_details()
+        # monitor_cpu_thread.daemon = True
+        # screen_shot_thread.daemon = True
 
-        thread_list.append(monitor_cpu_thread)
-        thread_list.append(screen_shot_thread)
-        for thread in thread_list:
-            thread.start()
-        # ScenarioMonitor.screenshot_thread.start()
+        # thread_list.append(monitor_cpu_thread)
+        # thread_list.append(screen_shot_thread)
+        # for thread in thread_list:
+        #     thread.start()
+        # sleep(10)
+        # self.method_name().get_screenshots()
 
     def stop(self, scenario, smartBOT):
-        for thread in thread_list:
-            thread.kill()
+        # for thread in thread_list:
+        #     thread.terminate()
+        screenshots = self.screenshot_generator(smartBOT).get_screenshots()
         scenario_time_lines = list()
         activity = get_base_activity()
         screenshot_statistics = [ScreenshotStatistics()]
-        ScenarioMonitor.screen_shot_generator.import_screenshots()
-        ScenarioMonitor.screen_shot_generator.update_screenshot_statistics(self.screen_shot_generator.screenshots)
+        self.screenshot_generator(smartBOT).import_screenshots()
+        get_cpu_stats = self.cpu_monitor(smartBOT).get_cpu_stats()
 
-        for cpu_stats in self.cpu_stats:
+        for cpu_stats in get_cpu_stats:
             screenshot_statistics_optional = Optional.empty()
             screenshot_statistics_optional.if_present(screenshot_statistics[0])
             self.set_screenshot_statistics_for_monitoring_off(screenshot_statistics[0])
             scenario_time_line = self.get_scenario_timeline(None, None, cpu_stats.interval, None,
                                                             screenshot_statistics[0])
             scenario_time_lines.append(scenario_time_line)
-        self.screen_shot_generator.delete_image_folder()
+        self.screenshot_generator(smartBOT).delete_image_folder()
         ScenariosServiceImpl().update_scenario_time_line(scenario=scenario, smartBOT=smartBOT,
                                                          scenario_time_lines=scenario_time_lines)
         Commons().delete_temp_folder(smartBOT)
@@ -97,6 +97,12 @@ class ScenarioMonitor(object):
             scenario_timeline.screenshotData = screenshot_stats.screenshot
         return scenario_timeline
 
+    def screenshot_generator(self, smartBOT):
+        return ScreenShotGenerator(smartBOT)
+
+    def cpu_monitor(self, smartBOT):
+        return CpuMonitor(smartBOT)
+
 
 def get_base_activity():
     activity = Activity()
